@@ -77,7 +77,7 @@ def send_notifications(email, sender, email_configuration):
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open('media/Zipped_file.zip', 'rb').read())
-    os.remove('Zipped_file.zip')
+    os.remove('media/Zipped_file.zip')
 
     # Add a header to tell the email client to treat this part as an
     # attachment, and to give the attachment a name.
