@@ -47,7 +47,7 @@ class EmailConfiguration(TimeStampedModel):
 
     LOG_TYPE_CHOICES = (
         ('attachment', 'ATTACHMENT'),
-        ('msg', 'MESSAGE'),
+        ('message', 'MESSAGE'),
     )
 
     Subject = models.CharField(max_length=200,
